<?php
/**
* @package		EasyBlog YooTheme
* @copyright	Copyright (C) Stack Ideas Sdn Bhd. All rights reserved.
* @license 		GNU/GPL, see LICENSE.php
* EasyBlog is free software. This version may have been modified pursuant
* to the GNU General Public License, and as distributed it includes or
* is derivative of works licensed under the GNU General Public License or
* other free or open source software licenses.
* See COPYRIGHT.php for copyright notices and details.
*/
defined('_JEXEC') or die('Unauthorized Access');

use Joomla\CMS\HTML\HTMLHelper;

$itemEl = $this->el('div', [
	'class' => ['yoo-eb-item'],
	'data-post-id' => $post->id,
]);

$coverEl = $this->el('div', [
	'class' => ['el-cover']
]);

$imageEl = $this->el('div', [
	'class' => ['el-image'],
	'style' => [
		"background-image: url('" . $post->getImage() . "');",
		"background-position: center;",
		"background-size: cover;",
		"height: " . $props['cover_height'] . "px;"
	]
]);

$titleEl = $this->el($props['title_element'], [
	'class' => [
		'el-title',
		'uk-{title_style}',
		'uk-card-title {@panel_style} {@!title_style}',
		'uk-heading-{title_decoration}',
		'uk-font-{title_font_family}',
		'uk-text-{title_color} {@!title_color: background}',
		'uk-margin[-{title_margin}]-top {@!title_margin: remove}',
		'uk-margin-remove-top {@title_margin: remove}',
		'uk-margin-remove-bottom',
	],
]);

$metaEl = $this->el('div', [
	'class' => ['el-meta uk-text-meta uk-margin-top'],
]);

$content = $this->el('div', [
	'class' => [
		'el-content uk-panel',
		'uk-text-{content_style}',
		'[uk-text-left{@content_align}]',
		'uk-dropcap {@content_dropcap}',
		'uk-column-{content_column}[@{content_column_breakpoint}]',
		'uk-column-divider {@content_column} {@content_column_divider}',
		'uk-margin[-{content_margin}]-top {@!content_margin: remove}',
	],
]);

$linkContainer = $this->el('div', [
    'class' => [
        'uk-margin[-{link_margin}]-top {@!link_margin: remove}',
    ],
]);

$link = $this->el('a', [
	'class' => [
		'el-link',
		'uk-{link_style: link-(muted|text)}',
		'uk-button uk-button-{!link_style: |link-muted|link-text} [uk-button-{link_size}] [uk-width-1-1 {@link_fullwidth}]',
		'uk-transition-{link_transition} {@overlay_hover}',
		// Keep link style if overlay link
		'uk-link {@link_style:} {@overlay_link}',
		'uk-text-muted {@link_style: link-muted} {@overlay_link}',
	],
    'href' => $post->getPermalink(),
    'title' => $post->getTitle(),
]);

$link->attr([
    'target' => ['_blank {@link_target}'],
]);

?>

<?= $itemEl($props) ?>
	<?php if ($props['show_cover']) { ?>
		<?= $coverEl ?>
			<?php if ($post->getCoverType() === EB_TYPE_VIDEO) { ?>
				<?php
					$video = $post->isEmbedCover() ?  $post->getEmbedCover() : \EB::media()->renderVideoPlayer($cover, ['width' => '260', 'height' => '200', 'ratio' => '', 'muted' => false, 'autoplay' => false, 'loop' => false], false);
					echo $video;
				?>
			<?php } else { ?>
				<?= $imageEl ?></div>
			<?php } ?>
		</div>
	<?php } ?>

	<?php if ($props['show_title']) { ?>
		<?php if ($props['title_link']) { ?>
			<?= $this->link($titleEl($props, $post->getTitle()), $post->getPermalink(), [
				'class' => ['el-link']
			]) ?>
		<?php } else { ?>
			<?= $titleEl($props, $post->getTitle()) ?>
		<?php } ?>
	<?php } ?>

	<?php if ($props['show_date'] || $props['show_categories'] || $props['show_author']) { ?>
		<?= $metaEl($props) ?>
			<?php if ($props['show_date']) { ?>
				<?= HTMLHelper::_('date', $post->getPublishDate()->toSql(), 'DATE_FORMAT_LC3'); ?>
			<?php } ?>

			<?php if ($props['show_categories']) { ?>
				<?php foreach ($post->getCategories() as $category) { ?>
					<?= $this->link($category->getTitle(), $category->getPermalink(), [
						'class' => ['el-link']
					]) ?>
				<?php } ?>
			<?php } ?>

			<?php if ($props['show_author']) { ?>
				<?php echo $post->getAuthorName();?>
			<?php } ?>
		</div>
	<?php } ?>

	<?php if ($props['show_content']) { ?>
		<?= $content($props, $post->getIntro(true, true, 'intro', $props['content_truncate'])) ?>
	<?php } ?>

	<?php if ($props['show_link']) { ?>
		<?= $linkContainer($props, $link($props, $props['link_text'])) ?>
	<?php } ?>
</div>